==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Repository/Repository.php <==
<?php
namespace Claromentis\Core\Repository;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array("_9b641a39cea831d2a1ba430f" . "e9660326" => base64_decode("U0VMRUNUIENPVU5U" . "KDEpIEZST00g"), "_665bffc6220b6" . "737c670c0517ea" . "fec78" => base64_decode("IFdIRVJFIA=" . "="), "_c5755b4703f57d87d04186ec7585" . "92b9" => base64_decode("Y29tbW9uL" . "m5vdF9mb3" . "VuZA=="), "_c3df8c593000fc4fe775" . "13bd0f1ee1c5" => base64_decode("T2JqZWN0ICM" . "="), "_0c5123aa74" . "4f69bbc0e8b" . "3ea2f6e847d" => base64_decode("bG1zZw" . "=="), "_8ab6ddf42" . "088608c501" . "fcded8995e" . "76c" => base64_decode("IA=" . "="));
use Claromentis\Core\Repository\Exception;
use Claromentis\Core\DAL;






class Repository
{
    protected $db;
    protected $stor;
    protected $object;
    public function __construct(DAL\Db $db, RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        $this->db = $db;
        $this->stor = \ObjectsStorage::I();
        $this->object = $_b15aac3aa29c10ea6d1228f58cb9a7e8;
    }
    
    
    
    
    
    
    public function NewObject()
    {
        return new $this->object();
    }
    
    
    
    
    
    
    
    
    public function Get($id)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8 = $this->NewObject();
        if (!$this->stor->Load($_b15aac3aa29c10ea6d1228f58cb9a7e8, $id)) {
            throw new Exception\NotFoundException($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_c3df8c593" . "000fc4fe77" . "513bd0f1ee" . "1c5"] . $id . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_8ab6ddf42088608c501fc" . "ded8995e76c"] . $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_0c5123aa744f69bbc0e8b3ea2f6e" . "847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_c5755b4703f57d87d041" . "86ec758592b9"]));
        }
        
        
        return $_b15aac3aa29c10ea6d1228f58cb9a7e8;
    }
    
    
    
    
    
    
    protected function AddRepository($_376d30c40857357a4d4cbb1ffaa25817)
    {
        foreach ($_376d30c40857357a4d4cbb1ffaa25817 as $_68ffaaa31e3ba49ed9d6159fbee9f043) {
            if (!isset($_68ffaaa31e3ba49ed9d6159fbee9f043)) {
                $_68ffaaa31e3ba49ed9d6159fbee9f043 = new \stdClass();
            }
            $_68ffaaa31e3ba49ed9d6159fbee9f043->repository = $this;
        }
    }
    
    
    
    
    public function Save(RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8->SaveTo($this->stor);
        
        
        
        
        
        
        
        
        
        
    }
    
    
    
    
    
    
    public function Delete(RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        return $this->stor->Delete($_b15aac3aa29c10ea6d1228f58cb9a7e8);
    }
    
    
    
    
    
    
    
    
    
    public function GetObjects(DAL\QueryPart $_03e9164d0a343b742df4793268b80767 = null, $_3b0b788afd03419829052390c6bd8208 = null, $_f11369824f533e8206f9ccc0c9aab3a0 = 0, $_1f50e30be8c2fefa6881834e71d504a2 = 0)
    {
        
        
        $_c5aeb46d4987229cd0033323a7f86836 = $this->stor->GetMultiple($this->NewObject(), $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208, $_f11369824f533e8206f9ccc0c9aab3a0, $_1f50e30be8c2fefa6881834e71d504a2);
        $this->AddRepository($_c5aeb46d4987229cd0033323a7f86836);
        return $_c5aeb46d4987229cd0033323a7f86836;
    }
    
    
    
    
    
    
    
    public function GetObjectsExt(callable $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208 = null)
    {
        
        
        $_c5aeb46d4987229cd0033323a7f86836 = $this->stor->GetMultipleExt($this->NewObject(), $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208);
        $this->AddRepository($_c5aeb46d4987229cd0033323a7f86836);
        return $_c5aeb46d4987229cd0033323a7f86836;
    }
    
    
    
    
    
    
    public function GetObjectsCount(DAL\QueryPart $_03e9164d0a343b742df4793268b80767)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8 = $this->NewObject();
        $_6555f4024e92c4a6b9140e99cd668e2b = $this->stor->GetDbTable($_b15aac3aa29c10ea6d1228f58cb9a7e8);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = new DAL\Query($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_9b641a39cea831d2a1ba" . "430fe9660326"] . $_6555f4024e92c4a6b9140e99cd668e2b . $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_665bffc62" . "20b6737c67" . "0c0517eafe" . "c78"] . $_03e9164d0a343b742df4793268b80767->AsPart());
        $_7f5aa4e96d4b415a86ed72ebff677cbe->BindPart($_03e9164d0a343b742df4793268b80767);
        list($_f53d35a1a1e233d98d9ce73d92ab3bb1) = $this->db->query_row($_7f5aa4e96d4b415a86ed72ebff677cbe);
        return $_f53d35a1a1e233d98d9ce73d92ab3bb1;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Repository/Repository.php <==
<?php
namespace Claromentis\Core\Repository;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array("_8ab6ddf42088608c501fcded89" . "95e76c" => base64_decode("IA=" . "="), "_0c5123aa744f69bbc0e8b3ea2f6e84" . "7d" => base64_decode("bG1zZ" . "w=="), "_665bffc622" . "0b6737c670c" . "0517eafec78" => base64_decode("IFdIRVJ" . "FIA=="), "_c3df8c593000fc4fe7" . "7513bd0f1ee1c5" => base64_decode("T2JqZ" . "WN0IC" . "M="), "_c5755b47" . "03f57d87d" . "04186ec75" . "8592b9" => base64_decode("Y29tbW9uLm5vdF9" . "mb3VuZA=="), "_9b641a39cea831d2a1" . "ba430fe9660326" => base64_decode("U0VMRUNUIE" . "NPVU5UKDEp" . "IEZST00g"));
use Claromentis\Core\Repository\Exception;
use Claromentis\Core\DAL;






class Repository
{
    protected $db;
    protected $stor;
    protected $object;
    public function __construct(DAL\Db $db, RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        $this->db = $db;
        $this->stor = \ObjectsStorage::I();
        $this->object = $_b15aac3aa29c10ea6d1228f58cb9a7e8;
    }
    
    
    
    
    
    
    public function NewObject()
    {
        return new $this->object();
    }
    
    
    
    
    
    
    
    
    public function Get($id)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8 = $this->NewObject();
        if (!$this->stor->Load($_b15aac3aa29c10ea6d1228f58cb9a7e8, $id)) {
            throw new Exception\NotFoundException($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_c3df8c593000fc4f" . "e77513bd0f1ee1c5"] . $id . $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_8ab6ddf420886" . "08c501fcded899" . "5e76c"] . $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_0c5123aa7" . "44f69bbc0e" . "8b3ea2f6e8" . "47d"]($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_c5755b47" . "03f57d87d" . "04186ec75" . "8592b9"]));
        }
        
        
        return $_b15aac3aa29c10ea6d1228f58cb9a7e8;
    }
    
    
    
    
    
    
    protected function AddRepository($_376d30c40857357a4d4cbb1ffaa25817)
    {
        foreach ($_376d30c40857357a4d4cbb1ffaa25817 as $_68ffaaa31e3ba49ed9d6159fbee9f043) {
            if (!isset($_68ffaaa31e3ba49ed9d6159fbee9f043)) {
                $_68ffaaa31e3ba49ed9d6159fbee9f043 = new \stdClass();
            }
            $_68ffaaa31e3ba49ed9d6159fbee9f043->repository = $this;
        }
    }
    
    
    
    
    public function Save(RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8->SaveTo($this->stor);
        
        
        
        
        
        
        
        
        
        
    }
    
    
    
    
    
    
    public function Delete(RepositoryItem $_b15aac3aa29c10ea6d1228f58cb9a7e8)
    {
        return $this->stor->Delete($_b15aac3aa29c10ea6d1228f58cb9a7e8);
    }
    
    
    
    
    
    
    
    
    
    public function GetObjects(DAL\QueryPart $_03e9164d0a343b742df4793268b80767 = null, $_3b0b788afd03419829052390c6bd8208 = null, $_f11369824f533e8206f9ccc0c9aab3a0 = 0, $_1f50e30be8c2fefa6881834e71d504a2 = 0)
    {
        
        
        $_c5aeb46d4987229cd0033323a7f86836 = $this->stor->GetMultiple($this->NewObject(), $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208, $_f11369824f533e8206f9ccc0c9aab3a0, $_1f50e30be8c2fefa6881834e71d504a2);
        $this->AddRepository($_c5aeb46d4987229cd0033323a7f86836);
        return $_c5aeb46d4987229cd0033323a7f86836;
    }
    
    
    
    
    
    
    
    public function GetObjectsExt(callable $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208 = null)
    {
        
        
        $_c5aeb46d4987229cd0033323a7f86836 = $this->stor->GetMultipleExt($this->NewObject(), $_03e9164d0a343b742df4793268b80767, $_3b0b788afd03419829052390c6bd8208);
        $this->AddRepository($_c5aeb46d4987229cd0033323a7f86836);
        return $_c5aeb46d4987229cd0033323a7f86836;
    }
    
    
    
    
    
    
    public function GetObjectsCount(DAL\QueryPart $_03e9164d0a343b742df4793268b80767)
    {
        $_b15aac3aa29c10ea6d1228f58cb9a7e8 = $this->NewObject();
        $_6555f4024e92c4a6b9140e99cd668e2b = $this->stor->GetDbTable($_b15aac3aa29c10ea6d1228f58cb9a7e8);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = new DAL\Query($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_9b641a39cea8" . "31d2a1ba430fe" . "9660326"] . $_6555f4024e92c4a6b9140e99cd668e2b . $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_665bffc6220b6737c670c05" . "17eafec78"] . $_03e9164d0a343b742df4793268b80767->AsPart());
        $_7f5aa4e96d4b415a86ed72ebff677cbe->BindPart($_03e9164d0a343b742df4793268b80767);
        list($_f53d35a1a1e233d98d9ce73d92ab3bb1) = $this->db->query_row($_7f5aa4e96d4b415a86ed72ebff677cbe);
        return $_f53d35a1a1e233d98d9ce73d92ab3bb1;
    }
}
